@@ -1,6 +1,6 @@
-from .pyaaware import _SEDConfig
-from .pyaaware import _SED
-from .sed import SED
+from .pyaaware import _FeatureGeneratorConfig
+from .pyaaware import _FeatureGenerator
+from .feature_generator import FeatureGenerator
 
 from .pyaaware import _ForwardTransformConfig
 from .pyaaware import _ForwardTransform
@@ -10,6 +10,10 @@ from .pyaaware import _InverseTransformConfig
 from .pyaaware import _InverseTransform
 from .inverse_transform import InverseTransform
 
-from .pyaaware import _FeatureGeneratorConfig
-from .pyaaware import _FeatureGenerator
-from .feature_generator import FeatureGenerator
+from .pyaaware import _NNPDetectConfig
+from .pyaaware import _NNPDetect
+from .nnp_detect import NNPDetect
+
+from .pyaaware import _SEDConfig
+from .pyaaware import _SED
+from .sed import SED
